@@ -25,7 +25,7 @@ use Cwd;
 use Carp;
 use YAML::XS;
 use File::Spec;
-use FindBin qw( $Bin $RealBin );
+use FindBin qw( $Bin $RealBin $Script $RealScript );
 
 sub new
 {
@@ -129,8 +129,10 @@ sub macro
 
     if ( $path )
     {
-        $path =~ s/\$Bin\b/$Bin/g; $path =~ s/\$RealBin\b/$RealBin/g;
-        $path =~ s/\${Bin}/$Bin/g; $path =~ s/\${RealBin}/$RealBin/g;
+        $path =~ s/\$Bin\b/$Bin/g; $path =~ s/\$RealScript\b/$RealScript/g;
+        $path =~ s/\${Bin}/$Bin/g; $path =~ s/\${RealScript}/$RealScript/g;
+        $path =~ s/\$Script\b/$Script/g; $path =~ s/\$RealBin\b/$RealBin/g;
+        $path =~ s/\${Script}/$Script/g; $path =~ s/\${RealBin}/$RealBin/g;
     }
 
     return $path;
